@@ -2,7 +2,7 @@
 /**
  * function used in server privilege pages
  *
- * @version $Id: server_privileges.js 10929 2007-11-15 17:51:46Z lem9 $
+ * @version $Id$
  */
 
 /**
@@ -71,38 +71,25 @@ function checkAddUser(the_form)
 
 
 /**
- * Generate a new password, which may then be copied to the form
- * with suggestPasswordCopy().
+ * Generate a new password and copy it to the password input areas
  *
- * @param   string   the form name
+ * @param   object   the form that holds the password fields
  *
  * @return  boolean  always true
  */
-function suggestPassword() {
+function suggestPassword(passwd_form) {
     // restrict the password to just letters and numbers to avoid problems:
     // "editors and viewers regard the password as multiple words and
     // things like double click no longer work"
     var pwchars = "abcdefhjmnpqrstuvwxyz23456789ABCDEFGHJKLMNPQRSTUVWYXZ";
     var passwordlength = 16;    // do we want that to be dynamic?  no, keep it simple :)
-    var passwd = document.getElementById('generated_pw');
+    var passwd = passwd_form.generated_pw;
     passwd.value = '';
 
     for ( i = 0; i < passwordlength; i++ ) {
         passwd.value += pwchars.charAt( Math.floor( Math.random() * pwchars.length ) )
     }
-    return passwd.value;
-}
-
-
-/**
- * Copy the generated password (or anything in the field) to the form
- *
- * @param   string   the form name
- *
- * @return  boolean  always true
- */
-function suggestPasswordCopy() {
-    document.getElementById('text_pma_pw').value = document.getElementById('generated_pw').value;
-    document.getElementById('text_pma_pw2').value = document.getElementById('generated_pw').value;
+    passwd_form.text_pma_pw.value = passwd.value;
+    passwd_form.text_pma_pw2.value = passwd.value;
     return true;
 }
