@@ -2,7 +2,7 @@
 /**
  * PHPExcel
  *
- * Copyright (c) 2006 - 2009 PHPExcel
+ * Copyright (c) 2006 - 2010 PHPExcel
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,45 +20,18 @@
  *
  * @category   PHPExcel
  * @package    PHPExcel_Writer
- * @copyright  Copyright (c) 2006 - 2009 PHPExcel (http://www.codeplex.com/PHPExcel)
+ * @copyright  Copyright (c) 2006 - 2010 PHPExcel (http://www.codeplex.com/PHPExcel)
  * @license    http://www.gnu.org/licenses/old-licenses/lgpl-2.1.txt	LGPL
- * @version    1.7.0, 2009-08-10
+ * @version    1.7.3c, 2010-06-01
  */
 
 
-/** PHPExcel root directory */
-if (!defined('PHPEXCEL_ROOT')) {
-	/**
-	 * @ignore
-	 */
-	define('PHPEXCEL_ROOT', dirname(__FILE__) . '/../../');
-}
-
-/** PHPExcel_IWriter */
-require_once PHPEXCEL_ROOT . 'PHPExcel/Writer/IWriter.php';
-
-/** PHPExcel_Cell */
-require_once PHPEXCEL_ROOT . 'PHPExcel/Cell.php';
-
-/** PHPExcel_RichText */
-require_once PHPEXCEL_ROOT . 'PHPExcel/RichText.php';
-
-/** PHPExcel_Shared_Drawing */
-require_once PHPEXCEL_ROOT . 'PHPExcel/Shared/Drawing.php';
-
-/** PHPExcel_Shared_String */
-require_once PHPEXCEL_ROOT . 'PHPExcel/Shared/String.php';
-
-/** PHPExcel_HashTable */
-require_once PHPEXCEL_ROOT . 'PHPExcel/HashTable.php';
-
-
 /**
  * PHPExcel_Writer_HTML
  *
  * @category   PHPExcel
  * @package    PHPExcel_Writer
- * @copyright  Copyright (c) 2006 - 2009 PHPExcel (http://www.codeplex.com/PHPExcel)
+ * @copyright  Copyright (c) 2006 - 2010 PHPExcel (http://www.codeplex.com/PHPExcel)
  */
 class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 	/**
@@ -88,14 +61,14 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 	 * @var string
 	 */
 	private $_imagesRoot = '.';
-	
+
 	/**
 	 * Use inline CSS?
 	 *
 	 * @var boolean
 	 */
 	private $_useInlineCss = false;
-	
+
 	/**
 	 * Array of CSS styles
 	 *
@@ -111,11 +84,39 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 	private $_columnWidths = null;
 
 	/**
-	 * Default font size
+	 * Default font
 	 *
-	 * @var int
+	 * @var PHPExcel_Style_Font
 	 */
-	private $_defaultFontSize;
+	private $_defaultFont;
+
+	/**
+	 * Flag whether spans have been calculated
+	 *
+	 * @var boolean
+	 */
+	private $_spansAreCalculated;
+
+	/**
+	 * Excel cells that should not be written as HTML cells
+	 *
+	 * @var array
+	 */
+	private $_isSpannedCell;
+
+	/**
+	 * Excel cells that are upper-left corner in a cell merge
+	 *
+	 * @var array
+	 */
+	private $_isBaseCell;
+
+	/**
+	 * Excel rows that should not be written as HTML rows
+	 *
+	 * @var array
+	 */
+	private $_isSpannedRow;
 
 	/**
 	 * Is the current writer creating PDF?
@@ -131,9 +132,14 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 	 */
 	public function __construct(PHPExcel $phpExcel) {
 		$this->_phpExcel = $phpExcel;
-		$this->_defaultFontSize = $this->_phpExcel->getDefaultStyle()->getFont()->getSize();
+		$this->_defaultFont = $this->_phpExcel->getDefaultStyle()->getFont();
 		$this->_sheetIndex = 0;
 		$this->_imagesRoot = '.';
+
+		$this->_spansAreCalculated = false;
+		$this->_isSpannedCell = array();
+		$this->_isBaseCell    = array();
+		$this->_isSpannedRow  = array();
 	}
 
 	/**
@@ -151,7 +157,7 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 
 		// Build CSS
 		$this->buildCSS(!$this->_useInlineCss);
-		
+
 		// Open file
 		$fileHandle = fopen($pFilename, 'w');
 		if ($fileHandle === false) {
@@ -161,6 +167,11 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 		// Write headers
 		fwrite($fileHandle, $this->generateHTMLHeader(!$this->_useInlineCss));
 
+		// Write navigation (tabs)
+		if (!$this->_isPdf) {
+			fwrite($fileHandle, $this->generateNavigation());
+		}
+
 		// Write data
 		fwrite($fileHandle, $this->generateSheetData());
 
@@ -210,6 +221,7 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 			case PHPExcel_Style_Border::BORDER_NONE: return '0px';
 			case PHPExcel_Style_Border::BORDER_DASHED: return '1px dashed';
 			case PHPExcel_Style_Border::BORDER_DOTTED: return '1px dotted';
+			case PHPExcel_Style_Border::BORDER_DOUBLE: return '3px double';
 			case PHPExcel_Style_Border::BORDER_THICK: return '2px solid';
 			default: return '1px solid'; // map others to thin
 		}
@@ -286,6 +298,11 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 			throw new Exception('Internal PHPExcel object not set to an instance of an object.');
 		}
 
+		// Ensure that Spans have been calculated?
+		if (!$this->_spansAreCalculated) {
+			$this->_calculateSpans();
+		}
+
 		// Fetch sheets
 		$sheets = array();
 		if (is_null($this->_sheetIndex)) {
@@ -300,9 +317,6 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 		// Loop all sheets
 		$sheetId = 0;
 		foreach ($sheets as $sheet) {
-			// Get cell collection
-			$cellCollection = $sheet->getCellCollection();
-
 			// Write table header
 			$html .= $this->_generateTableHeader($sheet);
 
@@ -313,29 +327,71 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 	    	$dimension[1] = PHPExcel_Cell::coordinateFromString($dimension[1]);
 	    	$dimension[1][0] = PHPExcel_Cell::columnIndexFromString($dimension[1][0]) - 1;
 
-	    	// Loop trough cells
+	    	// row min,max
+			$rowMin = $dimension[0][1];
+			$rowMax = $dimension[1][1];
+			
+			// calculate start of <tbody>, <thead>
+			$tbodyStart = $rowMin;
+	    	$tbodyEnd   = $rowMax;
+			$theadStart = 0; // default: no <thead>
+			$theadEnd   = 0; // default: no </thead>
+			if ($sheet->getPageSetup()->isRowsToRepeatAtTopSet()) {
+				$rowsToRepeatAtTop = $sheet->getPageSetup()->getRowsToRepeatAtTop();
+				
+				// we can only support repeating rows that start at top row
+				if ($rowsToRepeatAtTop[0] == 1) {
+					$theadStart = $rowsToRepeatAtTop[0];
+					$theadEnd   = $rowsToRepeatAtTop[1];
+					$tbodyStart = $rowsToRepeatAtTop[1] + 1;
+				}
+			}
+			
+			// Loop through cells
 	    	$rowData = null;
-	    	for ($row = $dimension[0][1]; $row <= $dimension[1][1]; ++$row) {
+	    	for ($row = $rowMin; $row <= $rowMax; ++$row) {
 				// Start a new row
 				$rowData = array();
 
-				// Loop trough columns
+				// Loop through columns
 	    		for ($column = $dimension[0][0]; $column <= $dimension[1][0]; ++$column) {
 	    			// Cell exists?
 	    			if ($sheet->cellExistsByColumnAndRow($column, $row)) {
-	    				$rowData[$column] = $sheet->getCellByColumnAndRow($column, $row);
+	    				$rowData[$column] = $cell = $sheet->getCellByColumnAndRow($column, $row);
 	    			} else {
 	    				$rowData[$column] = '';
 	    			}
 	    		}
 
-	    		// Write row
-				$html .= $this->_generateRow($sheet, $rowData, $row - 1);
+	    		// <thead> ?
+				if ($row == $theadStart) {
+					$html .= '        <thead>' . "\r\n";
+				}
+
+	    		// <tbody> ?
+				if ($row == $tbodyStart) {
+					$html .= '        <tbody>' . "\r\n";
+				}
+
+				// Write row if there are HTML table cells in it
+				if ( !isset($this->_isSpannedRow[$sheet->getParent()->getIndex($sheet)][$row]) ) {
+					$html .= $this->_generateRow($sheet, $rowData, $row - 1);
+				}
+
+	    		// </thead> ?
+				if ($row == $theadEnd) {
+					$html .= '        </thead>' . "\r\n";
+				}
+
+	    		// </tbody> ?
+				if ($row == $tbodyEnd) {
+					$html .= '        </tbody>' . "\r\n";
+				}
 	    	}
 
 			// Write table footer
 			$html .= $this->_generateTableFooter();
-			
+
 			// Writing PDF?
 			if ($this->_isPdf)
 			{
@@ -343,7 +399,7 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 					$html .= '<tcpdf method="AddPage" />';
 				}
 			}
-			
+
 			// Next sheet
 			++$sheetId;
 		}
@@ -352,6 +408,48 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 		return $html;
 	}
 
+	/**
+	 * Generate sheet tabs
+	 *
+	 * @return	string
+	 * @throws Exception
+	 */
+	public function generateNavigation()
+	{
+		// PHPExcel object known?
+		if (is_null($this->_phpExcel)) {
+			throw new Exception('Internal PHPExcel object not set to an instance of an object.');
+		}
+
+		// Fetch sheets
+		$sheets = array();
+		if (is_null($this->_sheetIndex)) {
+			$sheets = $this->_phpExcel->getAllSheets();
+		} else {
+			$sheets[] = $this->_phpExcel->getSheet($this->_sheetIndex);
+		}
+
+		// Construct HTML
+		$html = '';
+
+		// Only if there are more than 1 sheets
+		if (count($sheets) > 1) {
+			// Loop all sheets
+			$sheetId = 0;
+
+			$html .= '<ul class="navigation">' . "\r\n";
+
+			foreach ($sheets as $sheet) {
+				$html .= '  <li class="sheet' . $sheetId . '"><a href="#sheet' . $sheetId . '">' . $sheet->getTitle() . '</a></li>' . "\r\n";
+				++$sheetId;
+			}
+
+			$html .= '</ul>' . "\r\n";
+		}
+
+		return $html;
+	}
+
 	/**
 	 * Generate image tag in cell
 	 *
@@ -408,7 +506,7 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 		if (is_null($this->_phpExcel)) {
 			throw new Exception('Internal PHPExcel object not set to an instance of an object.');
 		}
-		
+
 		// Build CSS
 		$css = $this->buildCSS($generateSurroundingHTML);
 
@@ -420,7 +518,7 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 			$html .= '    <style type="text/css">' . "\r\n";
 			$html .= '      html { ' . $this->_assembleCSS($css['html']) . ' }' . "\r\n";
 		}
-		
+
 		// Write all other styles
 		foreach ($css as $styleName => $styleDefinition) {
 			if ($styleName != 'html') {
@@ -436,7 +534,7 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 		// Return
 		return $html;
 	}
-	
+
 	/**
 	 * Build CSS styles
 	 *
@@ -449,12 +547,17 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 		if (is_null($this->_phpExcel)) {
 			throw new Exception('Internal PHPExcel object not set to an instance of an object.');
 		}
-		
+
 		// Cached?
 		if (!is_null($this->_cssStyles)) {
 			return $this->_cssStyles;
 		}
 
+		// Ensure that spans have been calculated
+		if (!$this->_spansAreCalculated) {
+			$this->_calculateSpans();
+		}
+
 		// Construct CSS
 		$css = array();
 
@@ -523,12 +626,12 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 
 			// col elements, loop through columnDimensions and set width
 			foreach ($sheet->getColumnDimensions() as $columnDimension) {
-				if (($width = PHPExcel_Shared_Drawing::cellDimensionToPixels($columnDimension->getWidth(), $this->_defaultFontSize)) >= 0) {
+				if (($width = PHPExcel_Shared_Drawing::cellDimensionToPixels($columnDimension->getWidth(), $this->_defaultFont)) >= 0) {
 					$width = PHPExcel_Shared_Drawing::pixelsToPoints($width);
 					$column = PHPExcel_Cell::columnIndexFromString($columnDimension->getColumnIndex()) - 1;
 					$this->_columnWidths[$sheetIndex][$column] = $width;
 					$css['table.sheet' . $sheetIndex . ' col.col' . $column]['width'] = $width . 'pt';
-					
+
 					if ($columnDimension->getVisible() === false) {
 						$css['table.sheet' . $sheetIndex . ' col.col' . $column]['visibility'] = 'collapse';
 						$css['table.sheet' . $sheetIndex . ' col.col' . $column]['*display'] = 'none'; // target IE6+7
@@ -542,7 +645,11 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 			// table.sheetN tr { }
 			$css['table.sheet' . $sheetIndex . ' tr'] = array();
 
-			$pt_height = $rowDimension->getRowHeight();
+			if ($rowDimension->getRowHeight() == -1) {
+				$pt_height = PHPExcel_Shared_Font::getDefaultRowHeightByFont($this->_phpExcel->getDefaultStyle()->getFont());
+			} else {
+				$pt_height = $rowDimension->getRowHeight();
+			}
 			$css['table.sheet' . $sheetIndex . ' tr']['height'] = $pt_height . 'pt';
 			if ($rowDimension->getVisible() === false) {
 				$css['table.sheet' . $sheetIndex . ' tr']['display']    = 'none';
@@ -556,7 +663,11 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 				// table.sheetN tr.rowYYYYYY { }
 				$css['table.sheet' . $sheetIndex . ' tr.row' . $row] = array();
 
-				$pt_height = $rowDimension->getRowHeight();
+				if ($rowDimension->getRowHeight() == -1) {
+					$pt_height = PHPExcel_Shared_Font::getDefaultRowHeightByFont($this->_phpExcel->getDefaultStyle()->getFont());
+				} else {
+					$pt_height = $rowDimension->getRowHeight();
+				}
 				$css['table.sheet' . $sheetIndex . ' tr.row' . $row]['height'] = $pt_height . 'pt';
 				if ($rowDimension->getVisible() === false) {
 					$css['table.sheet' . $sheetIndex . ' tr.row' . $row]['display'] = 'none';
@@ -569,7 +680,7 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 		if (is_null($this->_cssStyles)) {
 			$this->_cssStyles = $css;
 		}
-		
+
 		// Return
 		return $css;
 	}
@@ -730,15 +841,19 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 
 		// Construct HTML
 		$html = '';
-		
+
 		if (!$this->_useInlineCss) {
 			$gridlines = $pSheet->getShowGridLines() ? ' gridlines' : '';
-			$html .= '    <table border="0" cellpadding="0" cellspacing="0" class="sheet' . $sheetIndex . $gridlines . '">' . "\r\n";
+			$html .= '    <table border="0" cellpadding="0" cellspacing="0" id="sheet' . $sheetIndex . '" class="sheet' . $sheetIndex . $gridlines . '">' . "\r\n";
 		} else {
 			$style = isset($this->_cssStyles['table']) ?
 				$this->_assembleCSS($this->_cssStyles['table']) : '';
 
-			$html .= '    <table border="0" cellpadding="0" cellspacing="0" style="' . $style . '">' . "\r\n";
+			if ($this->_isPdf && $pSheet->getShowGridLines()) {
+				$html .= '    <table border="1" cellpadding="0" id="sheet' . $sheetIndex . '" cellspacing="0" style="' . $style . '">' . "\r\n";
+			} else {
+				$html .= '    <table border="0" cellpadding="0" id="sheet' . $sheetIndex . '" cellspacing="0" style="' . $style . '">' . "\r\n";
+			}
 		}
 
 		// Write <col> elements
@@ -776,7 +891,7 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 	 *
 	 * @param	PHPExcel_Worksheet 	$pSheet			PHPExcel_Worksheet
 	 * @param	array				$pValues		Array containing cells in a row
-	 * @param	int					$pRow			Row number
+	 * @param	int					$pRow			Row number (0-based)
 	 * @return	string
 	 * @throws	Exception
 	 */
@@ -784,23 +899,42 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 		if (is_array($pValues)) {
 			// Construct HTML
 			$html = '';
-			
+
 			// Sheet index
 			$sheetIndex = $pSheet->getParent()->getIndex($pSheet);
 
+			// TCPDF and breaks
+			if ($this->_isPdf && count($pSheet->getBreaks()) > 0) {
+				$breaks = $pSheet->getBreaks();
+
+				// check if a break is needed before this row
+				if (isset($breaks['A' . $pRow])) {
+					// close table: </table>
+					$html .= $this->_generateTableFooter();
+
+					// insert page break
+					$html .= '<tcpdf method="AddPage" />';
+
+					// open table again: <table> + <col> etc.
+					$html .= $this->_generateTableHeader($pSheet);
+				}
+			}
+
 			// Write row start
 			if (!$this->_useInlineCss) {
-				$html .= '        <tr class="row' . $pRow . '">' . "\r\n";
+				$html .= '          <tr class="row' . $pRow . '">' . "\r\n";
 			} else {
 				$style = isset($this->_cssStyles['table.sheet' . $sheetIndex . ' tr.row' . $pRow])
 					? $this->_assembleCSS($this->_cssStyles['table.sheet' . $sheetIndex . ' tr.row' . $pRow]) : '';
-					
-				$html .= '        <tr style="' . $style . '">' . "\r\n";
+
+				$html .= '          <tr style="' . $style . '">' . "\r\n";
 			}
 
 			// Write cells
 			$colNum = 0;
 			foreach ($pValues as $cell) {
+				$coordinate = PHPExcel_Cell::stringFromColumnIndex($colNum) . ($pRow + 1);
+
 				if (!$this->_useInlineCss) {
 					$cssClass = '';
 					$cssClass = 'column' . $colNum;
@@ -819,10 +953,12 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 
 				// PHPExcel_Cell
 				if ($cell instanceof PHPExcel_Cell) {
-
+					if (is_null($cell->getParent())) {
+						$cell->attach($pSheet);
+					}
 					// Value
 					if ($cell->getValue() instanceof PHPExcel_RichText) {
-						// Loop trough rich text elements
+						// Loop through rich text elements
 						$elements = $cell->getValue()->getRichTextElements();
 						foreach ($elements as $element) {
 							// Rich text start?
@@ -854,17 +990,16 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 						if ($this->_preCalculateFormulas) {
 							$cellData = PHPExcel_Style_NumberFormat::toFormattedString(
 								$cell->getCalculatedValue(),
-								$pSheet->getParent()->getCellXfByIndex( $cell->getXfIndex() )->getNumberFormat()->getFormatCode()
+								$pSheet->getParent()->getCellXfByIndex( $cell->getXfIndex() )->getNumberFormat()->getFormatCode(),
+								array($this, 'formatColor')
 							);
 						} else {
 							$cellData = PHPExcel_Style_NumberFormat::ToFormattedString(
 								$cell->getValue(),
-								$pSheet->getParent()->getCellXfByIndex( $cell->getXfIndex() )->getNumberFormat()->getFormatCode()
+								$pSheet->getParent()->getCellXfByIndex( $cell->getXfIndex() )->getNumberFormat()->getFormatCode(),
+								array($this, 'formatColor')
 							);
 						}
-
-						// Convert UTF8 data to PCDATA
-						$cellData = htmlspecialchars($cellData);
 					}
 
 					// replace leading spaces on each line with &nbsp;
@@ -873,11 +1008,6 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 					// convert newline "\n" to '<br>'
 					$cellData = str_replace("\n", '<br/>', $cellData);
 
-					// Check value
-					if ($cellData == '') {
-						$cellData = '&nbsp;';
-					}
-
 					// Extend CSS class?
 					if (!$this->_useInlineCss) {
 						$cssClass .= ' style' . $cell->getXfIndex();
@@ -895,40 +1025,30 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 							$cssClass['text-align'] = $this->_cssStyles['.' . $cell->getDataType()]['text-align'];
 						}
 					}
-				} else {
-					$cell = new PHPExcel_Cell(
-						PHPExcel_Cell::stringFromColumnIndex($colNum),
-						($pRow + 1),
-						'',
-						PHPExcel_Cell_DataType::TYPE_NULL,
-						$pSheet
-					);
 				}
 
 				// Hyperlink?
-				if ($cell->hasHyperlink() && !$cell->getHyperlink()->isInternal()) {
-					$cellData = '<a href="' . htmlspecialchars($cell->getHyperlink()->getUrl()) . '" title="' . htmlspecialchars($cell->getHyperlink()->getTooltip()) . '">' . $cellData . '</a>';
+				if ($pSheet->hyperlinkExists($coordinate) && !$pSheet->getHyperlink($coordinate)->isInternal()) {
+					$cellData = '<a href="' . htmlspecialchars($pSheet->getHyperlink($coordinate)->getUrl()) . '" title="' . htmlspecialchars($pSheet->getHyperlink($coordinate)->getTooltip()) . '">' . $cellData . '</a>';
 				}
 
-				// Column/rowspan
-				foreach ($pSheet->getMergeCells() as $cells) {
-					if ($cell->isInRange($cells)) {
-						list($first, ) = PHPExcel_Cell::splitRange($cells);
+				// Should the cell be written or is it swallowed by a rowspan or colspan?
+				$writeCell = ! ( isset($this->_isSpannedCell[$pSheet->getParent()->getIndex($pSheet)][$pRow + 1][$colNum])
+							&& $this->_isSpannedCell[$pSheet->getParent()->getIndex($pSheet)][$pRow + 1][$colNum] );
 
-						if ($first[0] == $cell->getCoordinate()) {
-							list($colSpan, $rowSpan) = PHPExcel_Cell::rangeDimension($cells);
-						} else {
-							$writeCell = false;
-						}
-
-						break;
-					}
+				// Colspan and Rowspan
+				$colspan = 1;
+				$rowspan = 1;
+				if (isset($this->_isBaseCell[$pSheet->getParent()->getIndex($pSheet)][$pRow + 1][$colNum])) {
+					$spans = $this->_isBaseCell[$pSheet->getParent()->getIndex($pSheet)][$pRow + 1][$colNum];
+					$rowSpan = $spans['rowspan'];
+					$colSpan = $spans['colspan'];
 				}
 
 				// Write
 				if ($writeCell) {
 					// Column start
-					$html .= '          <td';
+					$html .= '            <td';
 						if (!$this->_useInlineCss) {
 							$html .= ' class="' . $cssClass . '"';
 						} else {
@@ -936,14 +1056,13 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 							// We must explicitly write the width of the <td> element because TCPDF
 							// does not recognize e.g. <col style="width:42pt">
 							$width = 0;
-							$columnIndex = PHPExcel_Cell::columnIndexFromString($cell->getColumn()) - 1;
-							for ($i = $columnIndex; $i < $columnIndex + $colSpan; ++$i) {
+							for ($i = $colNum; $i < $colNum + $colSpan; ++$i) {
 								if (isset($this->_columnWidths[$sheetIndex][$i])) {
 									$width += $this->_columnWidths[$sheetIndex][$i];
 								}
 							}
 							$cssClass['width'] = $width . 'pt';
-							
+
 							// We must also explicitly write the height of the <td> element because TCPDF
 							// does not recognize e.g. <tr style="height:50pt">
 							if (isset($this->_cssStyles['table.sheet' . $sheetIndex . ' tr.row' . $pRow]['height'])) {
@@ -951,7 +1070,7 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 								$cssClass['height'] = $height;
 							}
 							//** end of redundant code **
-							
+
 							$html .= ' style="' . $this->_assembleCSS($cssClass) . '"';
 						}
 						if ($colSpan > 1) {
@@ -963,11 +1082,11 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 					$html .= '>';
 
 					// Image?
-					$html .= $this->_writeImageTagInCell($pSheet, $cell->getCoordinate());
+					$html .= $this->_writeImageTagInCell($pSheet, $coordinate);
 
 					// Cell data
 					$html .= $cellData;
-					
+
 					// Column end
 					$html .= '</td>' . "\r\n";
 				}
@@ -977,7 +1096,7 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 			}
 
 			// Write row end
-			$html .= '        </tr>' . "\r\n";
+			$html .= '          </tr>' . "\r\n";
 
 			// Return
 			return $html;
@@ -1042,7 +1161,7 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
     	$this->_imagesRoot = $pValue;
     	return $this;
     }
-    
+
     /**
      * Get use inline CSS?
      *
@@ -1085,4 +1204,122 @@ class PHPExcel_Writer_HTML implements PHPExcel_Writer_IWriter {
 		return $string;
 	}
 
+	/**
+	 * Add color to formatted string as inline style
+	 *
+	 * @param string $pValue Plain formatted value without color
+	 * @param string $pFormat Format code
+	 * @return string
+	 */
+	public function formatColor($pValue, $pFormat)
+	{
+		// Color information, e.g. [Red] is always at the beginning
+		$color = null; // initialize
+		$matches = array();
+
+		$color_regex = '/^\\[[a-zA-Z]+\\]/';
+		if (preg_match($color_regex, $pFormat, $matches)) {
+			$color = str_replace('[', '', $matches[0]);
+			$color = str_replace(']', '', $color);
+			$color = strtolower($color);
+		}
+
+		// convert to PCDATA
+		$value = htmlspecialchars($pValue);
+
+		// color span tag
+		if ($color !== null) {
+			$value = '<span style="color:' . $color . '">' . $value . '</span>';
+		}
+
+		return $value;
+	}
+
+	/**
+	 * Calculate information about HTML colspan and rowspan which is not always the same as Excel's
+	 */
+	private function _calculateSpans()
+	{
+		// Identify all cells that should be omitted in HTML due to cell merge.
+		// In HTML only the upper-left cell should be written and it should have
+		//   appropriate rowspan / colspan attribute
+		$sheetIndexes = $this->_sheetIndex !== null ?
+			array($this->_sheetIndex) : range(0, $this->_phpExcel->getSheetCount() - 1);
+
+		foreach ($sheetIndexes as $sheetIndex) {
+			$sheet = $this->_phpExcel->getSheet($sheetIndex);
+
+			$candidateSpannedRow  = array();
+
+			// loop through all Excel merged cells
+			foreach ($sheet->getMergeCells() as $cells) {
+				list($cells, ) = PHPExcel_Cell::splitRange($cells);
+				$first = $cells[0];
+				$last  = $cells[1];
+
+				list($fc, $fr) = PHPExcel_Cell::coordinateFromString($first);
+				$fc = PHPExcel_Cell::columnIndexFromString($fc) - 1;
+
+				list($lc, $lr) = PHPExcel_Cell::coordinateFromString($last);
+				$lc = PHPExcel_Cell::columnIndexFromString($lc) - 1;
+
+				// loop through the individual cells in the individual merge
+				for ($r = $fr; $r <= $lr; ++$r) {
+					// also, flag this row as a HTML row that is candidate to be omitted
+					$candidateSpannedRow[$r] = $r;
+
+					for ($c = $fc; $c <= $lc; ++$c) {
+						if ( !($c == $fc && $r == $fr) ) {
+							// not the upper-left cell (should not be written in HTML)
+							$this->_isSpannedCell[$sheetIndex][$r][$c] = array(
+								'baseCell' => array($fr, $fc),
+							);
+						} else {
+							// upper-left is the base cell that should hold the colspan/rowspan attribute
+							$this->_isBaseCell[$sheetIndex][$r][$c] = array(
+								'xlrowspan' => $lr - $fr + 1, // Excel rowspan
+								'rowspan'   => $lr - $fr + 1, // HTML rowspan, value may change
+								'xlcolspan' => $lc - $fc + 1, // Excel colspan
+								'colspan'   => $lc - $fc + 1, // HTML colspan, value may change
+							);
+						}
+					}
+				}
+			}
+
+			// Identify which rows should be omitted in HTML. These are the rows where all the cells
+			//   participate in a merge and the where base cells are somewhere above.
+			$countColumns = PHPExcel_Cell::columnIndexFromString($sheet->getHighestColumn());
+			foreach ($candidateSpannedRow as $rowIndex) {
+				if (isset($this->_isSpannedCell[$sheetIndex][$rowIndex])) {
+					if (count($this->_isSpannedCell[$sheetIndex][$rowIndex]) == $countColumns) {
+						$this->_isSpannedRow[$sheetIndex][$rowIndex] = $rowIndex;
+					};
+				}
+			}
+
+			// For each of the omitted rows we found above, the affected rowspans should be subtracted by 1
+			if ( isset($this->_isSpannedRow[$sheetIndex]) ) {
+				foreach ($this->_isSpannedRow[$sheetIndex] as $rowIndex) {
+					$adjustedBaseCells = array();
+					for ($c = 0; $c < $countColumns; ++$c) {
+						$baseCell = $this->_isSpannedCell[$sheetIndex][$rowIndex][$c]['baseCell'];
+
+						if ( !in_array($baseCell, $adjustedBaseCells) ) {
+
+							// subtract rowspan by 1
+							--$this->_isBaseCell[$sheetIndex][ $baseCell[0] ][ $baseCell[1] ]['rowspan'];
+							$adjustedBaseCells[] = $baseCell;
+						}
+					}
+				}
+			}
+
+			// TODO: Same for columns
+		}
+
+		// We have calculated the spans
+		$this->_spansAreCalculated = true;
+	}
+
 }
