@@ -84,6 +84,7 @@ function PMA_importRunQuery($sql = '', $full = '', $controluser = false)
 {
     global $import_run_buffer, $go_sql, $complete_query, $display_query,
         $sql_query, $my_die, $error, $reload,
+        $last_query_with_results,
         $skip_queries, $executed_queries, $max_sql_len, $read_multiply,
         $cfg, $sql_query_disabled, $db, $run_query, $is_superuser;
     $read_multiply = 1;
@@ -143,6 +144,7 @@ function PMA_importRunQuery($sql = '', $full = '', $controluser = false)
                             $a_aff_rows = (int)@PMA_DBI_affected_rows();
                             if ($a_num_rows > 0) {
                                 $msg .= $GLOBALS['strRows'] . ': ' . $a_num_rows;
+                                $last_query_with_results = $import_run_buffer['sql'];
                             } elseif ($a_aff_rows > 0) {
                                 $msg .= sprintf($GLOBALS['strRowsAffected'], $a_aff_rows);
                             } else {
@@ -301,9 +303,19 @@ function PMA_importGetNextChunk($size = 32768)
 
 /**
  * Returns the "Excel" column name (i.e. 1 = "A", 26 = "Z", 27 = "AA", etc.)
- * This algorithm only works up to ZZ. it fails on AAA (up to 701 columns) 
  *
- * @author  Derek Schaefer (derek.schaefer@gmail.com)
+ * This functions uses recursion to build the Excel column name.
+ *
+ * The column number (1-26) is converted to the responding ASCII character (A-Z) and returned.
+ *
+ * If the column number is bigger than 26 (= num of letters in alfabet),
+ * an extra character needs to be added. To find this extra character, the number is divided by 26 
+ * and this value is passed to another instance of the same function (hence recursion). 
+ * In that new instance the number is evaluated again, and if it is still bigger than 26, it is divided again 
+ * and passed to another instance of the same function. This continues until the number is smaller than 26.
+ * Then the last called function returns the corresponding ASCII character to the function that called it.
+ * Each time a called function ends an extra character is added to the column name.
+ * When the first function is reached, the last character is addded and the complete column name is returned.
  *
  * @access  public
  *
@@ -313,57 +325,75 @@ function PMA_importGetNextChunk($size = 32768)
  */
 function PMA_getColumnAlphaName($num)
 {
-    /* ASCII value for capital "A" */
-    $A = 65;
-    $sCol = "";
-    $iRemain = 0;
-    
-    /* This algorithm only works up to ZZ. it fails on AAA */
-    
-    if ($num > 701) {                
-        return $num;
-    } elseif ($num <= 26) {
-        if ($num == 0) {
-            $sCol = chr(($A + 26) - 1);
-        } else {
-            $sCol = chr(($A + $num) - 1);
-        }
-    } else {
-        $iRemain = (($num / 26)) - 1;
-        if (($num % 26) == 0) {
-            $sCol = PMA_getColumnAlphaName($iRemain) . PMA_getColumnAlphaName($num % 26);
-        } else {
-            $sCol = chr($A + $iRemain) . PMA_getColumnAlphaName($num % 26);
-        }
-    }
-    
-    return $sCol;
+	$A = 65; // ASCII value for capital "A"
+	$col_name = "";
+
+	if ($num > 26) {
+		$div = (int)($num / 26);
+		$remain = (int)($num % 26);
+
+		// subtract 1 of divided value in case the modulus is 0,
+		// this is necessary because A-Z has no 'zero'
+		if ($remain == 0) {
+			$div--;
+		}
+
+		// recursive function call
+		$col_name = PMA_getColumnAlphaName($div);
+		// use modulus as new column number
+		$num = $remain;
+	}
+
+	if ($num == 0) {
+		// use 'Z' if column number is 0,
+		// this is necessary because A-Z has no 'zero'
+		$col_name .= chr(($A + 26) - 1);
+	} else {
+		// convert column number to ASCII character
+		$col_name .= chr(($A + $num) - 1);
+	}
+
+	return $col_name;
 }
 
 /**
  * Returns the column number based on the Excel name.
- * So "A" = 1, "AZ" = 27, etc.
+ * So "A" = 1, "Z" = 26, "AA" = 27, etc.
  *
- * @author  Derek Schaefer (derek.schaefer@gmail.com)
+ * Basicly this is a base26 (A-Z) to base10 (0-9) conversion.
+ * It iterates through all characters in the column name and
+ * calculates the corresponding value, based on character value
+ * (A = 1, ..., Z = 26) and position in the string.
  *
  * @access  public
  *
  * @uses    strtoupper()
  * @uses    strlen()
- * @uses    count()
  * @uses    ord()
  * @param   string $name (i.e. "A", or "BC", etc.)
  * @return  int The column number
  */
 function PMA_getColumnNumberFromName($name) {
-    if (strlen($name) != 0) {
+    if (!empty($name)) {
         $name = strtoupper($name);
-        $num_chars = count($name);
-        $number = 0;
+        $num_chars = strlen($name);
+        $column_number = 0;
         for ($i = 0; $i < $num_chars; ++$i) {
-            $number += (ord($name[$i]) - 64);
+		// read string from back to front
+		$char_pos = ($num_chars - 1) - $i;
+
+		// convert capital character to ASCII value
+		// and subtract 64 to get corresponding decimal value
+		// ASCII value of "A" is 65, "B" is 66, etc.
+		// Decimal equivalent of "A" is 1, "B" is 2, etc.
+		$number = (ord($name[$char_pos]) - 64);
+
+		// base26 to base10 conversion : multiply each number
+		// with corresponding value of the position, in this case
+		// $i=0 : 1; $i=1 : 26; $i=2 : 676; ...
+		$column_number += $number * pow(26,$i);
         }
-        return $number;
+        return $column_number;
     } else {
         return 0;
     }
@@ -838,8 +868,8 @@ $import_notice = NULL;
  * @uses    SIZES
  * @uses    strcmp()
  * @uses    count()
- * @uses    ereg()
- * @uses    ereg_replace()
+ * @uses    preg_match()
+ * @uses    preg_replace()
  * @uses    PMA_isView()
  * @uses    PMA_backquote()
  * @uses    PMA_importRunQuery()
@@ -910,17 +940,17 @@ function PMA_buildSQL($db_name, &$tables, &$analyses = NULL, &$additional_sql =
          *
          * $pattern = 'CREATE (TABLE|VIEW|TRIGGER|FUNCTION|PROCEDURE)';
          */
-        $pattern = 'CREATE .*(TABLE)';
+        $pattern = '/CREATE .*(TABLE)/';
         $replacement = 'CREATE \\1 IF NOT EXISTS';
         
         /* Change CREATE statements to CREATE IF NOT EXISTS to support inserting into existing structures */
         for ($i = 0; $i < $additional_sql_len; ++$i) {
-            $additional_sql[$i] = ereg_replace($pattern, $replacement, $additional_sql[$i]);
+            $additional_sql[$i] = preg_replace($pattern, $replacement, $additional_sql[$i]);
             /* Execute the resulting statements */
             PMA_importRunQuery($additional_sql[$i], $additional_sql[$i]);
         }
     }
-    
+
     if ($analyses != NULL) {
         $type_array = array(NONE => "NULL", VARCHAR => "varchar", INT => "int", DECIMAL => "decimal");
         
@@ -998,7 +1028,7 @@ function PMA_buildSQL($db_name, &$tables, &$analyses = NULL, &$additional_sql =
                 }
                 
                 $tempSQLStr .= (($is_varchar) ? "'" : "");
-				$tempSQLStr .= (str_replace("'", "\'", (string)$tables[$i][ROWS][$j][$k]));
+				$tempSQLStr .= PMA_sqlAddslashes((string)$tables[$i][ROWS][$j][$k]);
 				$tempSQLStr .= (($is_varchar) ? "'" : "");
                 
 				if ($k != ($num_cols - 1)) {
@@ -1045,8 +1075,8 @@ function PMA_buildSQL($db_name, &$tables, &$analyses = NULL, &$additional_sql =
     
     /* Add the viewable structures from $additional_sql to $tables so they are also displayed */
     
-    $view_pattern = 'VIEW `[^`]+`\.`([^`]+)';
-    $table_pattern = 'CREATE TABLE IF NOT EXISTS `([^`]+)`';
+    $view_pattern = '@VIEW `[^`]+`\.`([^`]+)@';
+    $table_pattern = '@CREATE TABLE IF NOT EXISTS `([^`]+)`@';
     /* Check a third pattern to make sure its not a "USE `db_name`;" statement */
     
     $regs = array();
@@ -1055,10 +1085,10 @@ function PMA_buildSQL($db_name, &$tables, &$analyses = NULL, &$additional_sql =
     
     $additional_sql_len = count($additional_sql);
     for ($i = 0; $i < $additional_sql_len; ++$i) {
-        ereg($view_pattern, $additional_sql[$i], $regs);
+        preg_match($view_pattern, $additional_sql[$i], $regs);
         
         if (count($regs) == 0) {
-            ereg($table_pattern, $additional_sql[$i], $regs);
+            preg_match($table_pattern, $additional_sql[$i], $regs);
         }
         
         if (count($regs)) {
