@@ -5,7 +5,7 @@
  *
  * register_globals_save (mark this file save for disabling register globals)
  *
- * @version $Id: tbl_change.php 12918 2009-09-03 12:29:24Z lem9 $
+ * @version $Id$
  * @package phpMyAdmin
  */
 
@@ -19,21 +19,19 @@ require_once './libraries/common.inc.php';
  */
 require_once './libraries/db_table_exists.lib.php';
 
-
 /**
  * Sets global variables.
  * Here it's better to use a if, instead of the '?' operator
  * to avoid setting a variable to '' when it's not present in $_REQUEST
  */
-/**
- * @todo this one is badly named, it's really a WHERE condition
- *       and exists even for tables not having a primary key or unique key
- */
-if (isset($_REQUEST['primary_key'])) {
-    $primary_key = $_REQUEST['primary_key'];
+if (isset($_REQUEST['where_clause'])) {
+    $where_clause = $_REQUEST['where_clause'];
+}
+if (isset($_REQUEST['clause_is_unique'])) {
+    $clause_is_unique = $_REQUEST['clause_is_unique'];
 }
 if (isset($_SESSION['edit_next'])) {
-    $primary_key = $_SESSION['edit_next'];
+    $where_clause = $_SESSION['edit_next'];
     unset($_SESSION['edit_next']);
     $after_insert = 'edit_next';
 }
@@ -154,39 +152,42 @@ PMA_DBI_select_db($db);
 $table_fields = PMA_DBI_fetch_result('SHOW FIELDS FROM ' . PMA_backquote($table) . ';',
     null, null, null, PMA_DBI_QUERY_STORE);
 $rows               = array();
-if (isset($primary_key)) {
+if (isset($where_clause)) {
     // when in edit mode load all selected rows from table
     $insert_mode = false;
-    if (is_array($primary_key)) {
-        $primary_key_array = $primary_key;
+    if (is_array($where_clause)) {
+        $where_clause_array = $where_clause;
     } else {
-        $primary_key_array = array(0 => $primary_key);
+        $where_clause_array = array(0 => $where_clause);
     }
 
     $result             = array();
     $found_unique_key   = false;
-    foreach ($primary_key_array as $key_id => $primary_key) {
-        $local_query           = 'SELECT * FROM ' . PMA_backquote($db) . '.' . PMA_backquote($table) . ' WHERE ' . $primary_key . ';';
+    $where_clauses      = array();
+
+    foreach ($where_clause_array as $key_id => $where_clause) {
+        $local_query           = 'SELECT * FROM ' . PMA_backquote($db) . '.' . PMA_backquote($table) . ' WHERE ' . $where_clause . ';';
         $result[$key_id]       = PMA_DBI_query($local_query, null, PMA_DBI_QUERY_STORE);
         $rows[$key_id]         = PMA_DBI_fetch_assoc($result[$key_id]);
-        $primary_keys[$key_id] = str_replace('\\', '\\\\', $primary_key);
+        $where_clauses[$key_id] = str_replace('\\', '\\\\', $where_clause);
 
         // No row returned
         if (! $rows[$key_id]) {
-            unset($rows[$key_id], $primary_key_array[$key_id]);
+            unset($rows[$key_id], $where_clause_array[$key_id]);
             PMA_showMessage($strEmptyResultSet, $local_query);
             echo "\n";
             require_once './libraries/footer.inc.php';
-        } else { // end if (no record returned)
+        } else { // end if (no row returned)
             $meta = PMA_DBI_get_fields_meta($result[$key_id]);
-            if ($tmp = PMA_getUniqueCondition($result[$key_id], count($meta), $meta, $rows[$key_id], true)) {
+            list($unique_condition, $tmp_clause_is_unique) = PMA_getUniqueCondition($result[$key_id], count($meta), $meta, $rows[$key_id], true);
+            if (! empty($unique_condition)) {
                 $found_unique_key = true;
             }
-            unset($tmp);
+            unset($unique_condition, $tmp_clause_is_unique);
         }
     }
 } else {
-    // no primary key given, just load first row - but what happens if tbale is empty?
+    // no primary key given, just load first row - but what happens if table is empty?
     $insert_mode = true;
     $result = PMA_DBI_query('SELECT * FROM ' . PMA_backquote($db) . '.' . PMA_backquote($table) . ' LIMIT 1;', null, PMA_DBI_QUERY_STORE);
     $rows = array_fill(0, $cfg['InsertRows'], false);
@@ -228,11 +229,14 @@ $_form_params = array(
     'err_url'   => $err_url,
     'sql_query' => $sql_query,
 );
-if (isset($primary_keys)) {
-    foreach ($primary_key_array as $key_id => $primary_key) {
-        $_form_params['primary_key[' . $key_id . ']'] = trim($primary_key);
+if (isset($where_clauses)) {
+    foreach ($where_clause_array as $key_id => $where_clause) {
+        $_form_params['where_clause[' . $key_id . ']'] = trim($where_clause);
     }
 }
+if (isset($clause_is_unique)) {
+    $_form_params['clause_is_unique'] = $clause_is_unique;
+}
 
 ?>
 <!-- Insert/Edit form -->
@@ -257,8 +261,8 @@ $biggest_max_file_size = 0;
 // (currently does not work for multi-edits)
 $url_params['db'] = $db;
 $url_params['table'] = $table;
-if (isset($primary_key)) {
-    $url_params['primary_key'] = trim($primary_key);
+if (isset($where_clause)) {
+    $url_params['where_clause'] = trim($where_clause);
 }
 if (! empty($sql_query)) {
     $url_params['sql_query'] = $sql_query;
@@ -425,10 +429,7 @@ foreach ($rows as $row_id => $vrow) {
         $real_null_value = FALSE;
         $special_chars_encoded = '';
         if (isset($vrow)) {
-            // On a BLOB that can have a NULL value, the is_null() returns
-            // true if it has no content but for me this is different than
-            // having been set explicitely to NULL so I put an exception here
-            if (! $field['is_blob'] && is_null($vrow[$field['Field']])) {
+            if (is_null($vrow[$field['Field']])) {
                 $real_null_value = TRUE;
                 $vrow[$field['Field']]    = '';
                 $special_chars   = '';
@@ -437,8 +438,13 @@ foreach ($rows as $row_id => $vrow) {
                 $special_chars = PMA_printable_bit_value($vrow[$field['Field']], $extracted_fieldspec['spec_in_brackets']);
             } else {
                 // loic1: special binary "characters"
-                if ($field['is_binary'] || $field['is_blob']) {
-                    $vrow[$field['Field']] = PMA_replace_binary_contents($vrow[$field['Field']]);
+                if ($field['is_binary'] || ($field['is_blob'] && ! $cfg['ProtectBinary'])) {
+                	if ($_SESSION['tmp_user_values']['display_binary_as_hex'] && $cfg['ShowFunctionFields']) {
+                		$vrow[$field['Field']] = bin2hex($vrow[$field['Field']]);
+                		$field['display_binary_as_hex'] = true;
+					} else {
+                    	$vrow[$field['Field']] = PMA_replace_binary_contents($vrow[$field['Field']]);
+					}
                 } // end if
                 $special_chars   = htmlspecialchars($vrow[$field['Field']]);
 
@@ -455,6 +461,7 @@ foreach ($rows as $row_id => $vrow) {
                 . $field_name_appendix . '" value="'
                 . htmlspecialchars($vrow[$field['Field']]) . '" />';
         } else {
+            // (we are inserting)
             // loic1: display default values
             if (!isset($field['Default'])) {
                 $field['Default'] = '';
@@ -470,6 +477,10 @@ foreach ($rows as $row_id => $vrow) {
             }
             $backup_field  = '';
             $special_chars_encoded = PMA_duplicateFirstNewline($special_chars);
+            // this will select the UNHEX function while inserting
+            if (($field['is_binary'] || ($field['is_blob'] && ! $cfg['ProtectBinary'])) && $_SESSION['tmp_user_values']['display_binary_as_hex'] && $cfg['ShowFunctionFields']) {
+                $field['display_binary_as_hex'] = true;
+            }
         }
 
         $idindex  = ($o_rows * $fields_cnt) + $i + 1;
@@ -525,11 +536,20 @@ foreach ($rows as $row_id => $vrow) {
                     $default_function = $cfg['DefaultFunctions']['first_timestamp'];
                 }
 
-                if ($field['Key'] == 'PRI'
-                 && ($field['Type'] == 'char(36)' || $field['Type'] == 'varchar(36)')) {
+                // For primary keys of type char(36) or varchar(36) UUID if the default function
+                // Only applies to insert mode, as it would silently trash data on updates.
+                if ($insert_mode
+                    && $field['Key'] == 'PRI'
+                    && ($field['Type'] == 'char(36)' || $field['Type'] == 'varchar(36)')
+                ) {
                      $default_function = $cfg['DefaultFunctions']['pk_char36'];
                 }
 
+                // this is set only when appropriate and is always true
+				if (isset($field['display_binary_as_hex'])) {
+                	$default_function = 'UNHEX';
+				}
+
                 // garvin: loop on the dropdown array and print all available options for that field.
                 foreach ($dropdown as $each_dropdown){
                     echo '<option';
@@ -603,7 +623,7 @@ foreach ($rows as $row_id => $vrow) {
                     // foreign key in a drop-down
                     $onclick     .= '4, ';
                 } elseif ($foreigners && isset($foreigners[$field['Field']]) && $foreignData['foreign_link'] == true) {
-                    // foreign key with a browsing icon 
+                    // foreign key with a browsing icon
                     $onclick     .= '6, ';
                 } else {
                     $onclick     .= '5, ';
@@ -732,7 +752,7 @@ foreach ($rows as $row_id => $vrow) {
                     echo '<option value="' . $enum_value['html'] . '"';
                     if ($data == $enum_value['plain']
                      || ($data == ''
-                      && (! isset($primary_key) || $field['Null'] != 'YES')
+                      && (! isset($where_clause) || $field['Null'] != 'YES')
                       && isset($field['Default'])
                       && $enum_value['plain'] == $field['Default'])) {
                         echo ' selected="selected"';
@@ -753,7 +773,7 @@ foreach ($rows as $row_id => $vrow) {
                     echo $unnullify_trigger;
                     if ($data == $enum_value['plain']
                      || ($data == ''
-                      && (! isset($primary_key) || $field['Null'] != 'YES')
+                      && (! isset($where_clause) || $field['Null'] != 'YES')
                       && isset($field['Default'])
                       && $enum_value['plain'] == $field['Default'])) {
                         echo ' checked="checked"';
@@ -1081,7 +1101,7 @@ foreach ($rows as $row_id => $vrow) {
         <td valign="middle" nowrap="nowrap">
             <select name="submit_type" tabindex="<?php echo ($tabindex + $tabindex_for_value + 1); ?>">
 <?php
-if (isset($primary_key)) {
+if (isset($where_clause)) {
     ?>
                 <option value="<?php echo $strSave; ?>"><?php echo $strSave; ?></option>
     <?php
@@ -1105,15 +1125,15 @@ if (!isset($after_insert)) {
                 <option value="back" <?php echo ($after_insert == 'back' ? 'selected="selected"' : ''); ?>><?php echo $strAfterInsertBack; ?></option>
                 <option value="new_insert" <?php echo ($after_insert == 'new_insert' ? 'selected="selected"' : ''); ?>><?php echo $strAfterInsertNewInsert; ?></option>
 <?php
-if (isset($primary_key)) {
+if (isset($where_clause)) {
     ?>
                 <option value="same_insert" <?php echo ($after_insert == 'same_insert' ? 'selected="selected"' : ''); ?>><?php echo $strAfterInsertSame; ?></option>
     <?php
     // If we have just numeric primary key, we can also edit next
     // in 2.8.2, we were looking for `field_name` = numeric_value
-    //if (preg_match('@^[\s]*`[^`]*` = [0-9]+@', $primary_key)) {
+    //if (preg_match('@^[\s]*`[^`]*` = [0-9]+@', $where_clause)) {
     // in 2.9.0, we are looking for `table_name`.`field_name` = numeric_value
-    if ($found_unique_key && preg_match('@^[\s]*`[^`]*`[\.]`[^`]*` = [0-9]+@', $primary_key)) {
+    if ($found_unique_key && preg_match('@^[\s]*`[^`]*`[\.]`[^`]*` = [0-9]+@', $where_clause)) {
         ?>
     <option value="edit_next" <?php echo ($after_insert == 'edit_next' ? 'selected="selected"' : ''); ?>><?php echo $strAfterInsertNext; ?></option>
         <?php
@@ -1149,9 +1169,9 @@ if ($insert_mode) {
     <input type="hidden" name="err_url" value="<?php echo htmlspecialchars($err_url); ?>" />
     <input type="hidden" name="sql_query" value="<?php echo htmlspecialchars($sql_query); ?>" />
 <?php
-    if (isset($primary_keys)) {
-        foreach ($primary_key_array as $key_id => $primary_key) {
-            echo '<input type="hidden" name="primary_key[' . $key_id . ']" value="' . htmlspecialchars(trim($primary_key)) . '" />'. "\n";
+    if (isset($where_clauses)) {
+        foreach ($where_clause_array as $key_id => $where_clause) {
+            echo '<input type="hidden" name="where_clause[' . $key_id . ']" value="' . htmlspecialchars(trim($where_clause)) . '" />'. "\n";
         }
     }
     $tmp = '<select name="insert_rows" id="insert_rows" onchange="this.form.submit();" >' . "\n";
