@@ -1,9 +1,17 @@
 <?php
-/* $Id: tbl_printview.php 9202 2006-07-27 17:14:30Z lem9 $ */
+/* vim: set expandtab sw=4 ts=4 sts=4: */
+/**
+ *
+ * @version $Id$
+ * @package phpMyAdmin
+ */
 
-require_once './libraries/common.lib.php';
+/**
+ *
+ */
+require_once './libraries/common.inc.php';
 
-require './libraries/tbl_properties_common.php';
+require './libraries/tbl_common.php';
 
 /**
  * Gets the variables sent or posted to this script, then displays headers
@@ -24,17 +32,17 @@ if (! isset($the_tables) || ! is_array($the_tables)) {
  */
 require_once './libraries/relation.lib.php';
 require_once './libraries/transformations.lib.php';
-require_once './libraries/tbl_indexes.lib.php';
+require_once './libraries/Index.class.php';
 
 $cfgRelation = PMA_getRelationsParam();
 
 /**
  * Defines the url to return to in case of error in a sql statement
  */
-if (isset($table)) {
-    $err_url = 'tbl_properties.php?' . PMA_generate_common_url($db, $table);
+if (strlen($table)) {
+    $err_url = 'tbl_sql.php?' . PMA_generate_common_url($db, $table);
 } else {
-    $err_url = 'db_details.php?' . PMA_generate_common_url($db);
+    $err_url = 'db_sql.php?' . PMA_generate_common_url($db);
 }
 
 
@@ -50,7 +58,7 @@ PMA_DBI_select_db($db);
  */
 if (isset($selected_tbl) && is_array($selected_tbl)) {
     $the_tables   = $selected_tbl;
-} elseif (isset($table)) {
+} elseif (strlen($table)) {
     $the_tables[] = $table;
 }
 $multi_tables     = (count($the_tables) > 1);
@@ -62,9 +70,9 @@ if ($multi_tables) {
     $tbl_list     = '';
     foreach ($the_tables as $key => $table) {
         $tbl_list .= (empty($tbl_list) ? '' : ', ')
-                  . PMA_backquote(urldecode($table));
+                  . PMA_backquote($table);
     }
-    echo '<b>'.  $strShowTables . ': ' . $tbl_list . '</b>' . "\n";
+    echo '<strong>'.  $strShowTables . ': ' . $tbl_list . '</strong>' . "\n";
     echo '<hr />' . "\n";
 } // end if
 
@@ -72,7 +80,6 @@ $tables_cnt = count($the_tables);
 $counter    = 0;
 
 foreach ($the_tables as $key => $table) {
-    $table = urldecode($table);
     if ($counter + 1 >= $tables_cnt) {
         $breakstyle = '';
     } else {
@@ -85,23 +92,12 @@ foreach ($the_tables as $key => $table) {
     /**
      * Gets table informations
      */
-    $result       = PMA_DBI_query(
-        'SHOW TABLE STATUS LIKE \'' . PMA_sqlAddslashes($table, true) . '\';');
-    $showtable    = PMA_DBI_fetch_assoc($result);
+    $showtable    = PMA_Table::sGetStatusInfo($db, $table);
     $num_rows     = (isset($showtable['Rows']) ? $showtable['Rows'] : 0);
     $show_comment = (isset($showtable['Comment']) ? $showtable['Comment'] : '');
-    PMA_DBI_free_result($result);
 
     $tbl_is_view = PMA_Table::isView($db, $table);
 
-    //  Gets table keys and store them in arrays
-    $indexes      = array();
-    $indexes_info = array();
-    $indexes_data = array();
-    $ret_keys = PMA_get_indexes($table, $err_url_0);
-
-    PMA_extract_indexes($ret_keys, $indexes, $indexes_info, $indexes_data);
-
     /**
      * Gets fields properties
      */
@@ -110,7 +106,7 @@ foreach ($the_tables as $key => $table) {
         PMA_DBI_QUERY_STORE);
     $fields_cnt  = PMA_DBI_num_rows($result);
 
-    
+
 // We need this to correctly learn if a TIMESTAMP is NOT NULL, since
 // SHOW FULL FIELDS or INFORMATION_SCHEMA incorrectly says NULL
 // and SHOW CREATE TABLE says NOT NULL (tested
@@ -122,26 +118,16 @@ foreach ($the_tables as $key => $table) {
     $analyzed_sql = PMA_SQP_analyze(PMA_SQP_parse($show_create_table));
 
     // Check if we can use Relations (Mike Beck)
-    if (!empty($cfgRelation['relation'])) {
-        // Find which tables are related with the current one and write it in
-        // an array
-        $res_rel = PMA_getForeigners($db, $table);
-
-        if (count($res_rel) > 0) {
-            $have_rel = true;
-        } else {
-            $have_rel = false;
-        }
-    } else {
-           $have_rel = false;
-    } // end if
-
+    // Find which tables are related with the current one and write it in
+    // an array
+    $res_rel  = PMA_getForeigners($db, $table);
+    $have_rel = (bool) count($res_rel);
 
     /**
      * Displays the comments of the table if MySQL >= 3.23
      */
     if (!empty($show_comment)) {
-        echo $strTableComments . ': ' . $show_comment . '<br /><br />';
+        echo $strTableComments . ': ' . htmlspecialchars($show_comment) . '<br /><br />';
     }
 
     /**
@@ -163,9 +149,7 @@ foreach ($the_tables as $key => $table) {
     if ($have_rel) {
         echo '<th>' . $strLinksTo . '</th>' . "\n";
     }
-    if ($cfgRelation['commwork']) {
-        echo '    <th>' . $strComments . '</th>' . "\n";
-    }
+    echo '    <th>' . $strComments . '</th>' . "\n";
     if ($cfgRelation['mimework']) {
         echo '    <th>MIME</th>' . "\n";
     }
@@ -220,10 +204,12 @@ foreach ($the_tables as $key => $table) {
         // here, we have a TIMESTAMP that SHOW FULL FIELDS reports as having the
         // NULL attribute, but SHOW CREATE TABLE says the contrary. Believe
         // the latter.
-	// TODO: merge this logic with the one in tbl_properties_structure.php
-	// or move it in a function similar to PMA_DBI_get_columns_full()
-	// but based on SHOW CREATE TABLE because information_schema
-	// cannot be trusted in this case (MySQL bug)
+        /**
+         * @todo merge this logic with the one in tbl_structure.php
+         * or move it in a function similar to PMA_DBI_get_columns_full()
+         * but based on SHOW CREATE TABLE because information_schema
+         * cannot be trusted in this case (MySQL bug)
+         */
         if (!empty($analyzed_sql[0]['create_table_fields'][$field_name]['type']) && $analyzed_sql[0]['create_table_fields'][$field_name]['type'] == 'TIMESTAMP' && $analyzed_sql[0]['create_table_fields'][$field_name]['timestamp_not_null']) {
             $row['Null'] = '';
         }
@@ -247,18 +233,16 @@ foreach ($the_tables as $key => $table) {
     if ($have_rel) {
         echo '    <td>';
         if (isset($res_rel[$field_name])) {
-            echo htmlspecialchars($res_rel[$field_name]['foreign_table'] . ' -> ' . $res_rel[$field_name]['foreign_field'] );
+            echo htmlspecialchars($res_rel[$field_name]['foreign_table'] . ' -> ' . $res_rel[$field_name]['foreign_field']);
         }
         echo '&nbsp;</td>' . "\n";
     }
-    if ($cfgRelation['commwork'] || PMA_MYSQL_INT_VERSION >= 40100) {
-        echo '    <td>';
-        $comments = PMA_getComments($db, $table);
-        if (isset($comments[$field_name])) {
-            echo htmlspecialchars($comments[$field_name]);
-        }
-        echo '&nbsp;</td>' . "\n";
+    echo '    <td>';
+    $comments = PMA_getComments($db, $table);
+    if (isset($comments[$field_name])) {
+        echo htmlspecialchars($comments[$field_name]);
     }
+    echo '&nbsp;</td>' . "\n";
     if ($cfgRelation['mimework']) {
         $mime_map = PMA_getMIME($db, $table, true);
 
@@ -276,43 +260,12 @@ foreach ($the_tables as $key => $table) {
     ?>
 </tbody>
 </table>
-
     <?php
-
-    if ( ! $tbl_is_view
-      && ( $db != 'information_schema'
-        || PMA_MYSQL_INT_VERSION < 50002 ) ) {
-
+    if (! $tbl_is_view && $db != 'information_schema') {
         /**
          * Displays indexes
          */
-        $index_count = (isset($indexes))
-                     ? count($indexes)
-                     : 0;
-        if ($index_count > 0) {
-            echo "\n";
-            ?>
-    <br /><br />
-
-    <!-- Indexes -->
-    <big><?php echo $strIndexes . ':'; ?></big>
-    <table>
-        <tr>
-            <th><?php echo $strKeyname; ?></th>
-            <th><?php echo $strType; ?></th>
-            <th><?php echo $strCardinality; ?></th>
-            <th colspan="2"><?php echo $strField; ?></th>
-        </tr>
-            <?php
-            echo "\n";
-            PMA_show_indexes($table, $indexes, $indexes_info, $indexes_data, true, true);
-            echo "\n";
-            ?>
-    </table>
-            <?php
-            echo "\n";
-        } // end display indexes
-
+        echo PMA_Index::getView($table, $db, true);
 
         /**
          * Displays Space usage and row statistics
@@ -326,10 +279,9 @@ foreach ($the_tables as $key => $table) {
             }
             if ($nonisam == false) {
                 // Gets some sizes
-                $mergetable     = false;
-                if (isset($showtable['Type']) && $showtable['Type'] == 'MRG_MyISAM') {
-                    $mergetable = true;
-                }
+
+		$mergetable = PMA_Table::isMerge($db, $table);
+
                 list($data_size, $data_unit)         = PMA_formatByteDown($showtable['Data_length']);
                 if ($mergetable == false) {
                     list($index_size, $index_unit)   = PMA_formatByteDown($showtable['Index_length']);
@@ -426,7 +378,7 @@ foreach ($the_tables as $key => $table) {
                 <td align="<?php echo $cell_align_left; ?>">
                     <?php
                     if ($showtable['Row_format'] == 'Fixed') {
-                        echo $strFixed;
+                        echo $strStatic;
                     } elseif ($showtable['Row_format'] == 'Dynamic') {
                         echo $strDynamic;
                     } else {
@@ -442,7 +394,7 @@ foreach ($the_tables as $key => $table) {
             <tr>
                 <td><?php echo ucfirst($strRows); ?></td>
                 <td align="right">
-                    <?php echo number_format($showtable['Rows'], 0, $number_decimal_separator, $number_thousands_separator) . "\n"; ?>
+                    <?php echo PMA_formatNumber($showtable['Rows'], 0) . "\n"; ?>
                 </td>
             </tr>
                     <?php
@@ -452,7 +404,7 @@ foreach ($the_tables as $key => $table) {
             <tr>
                 <td><?php echo ucfirst($strRowLength); ?>&nbsp;&oslash;</td>
                 <td>
-                    <?php echo number_format($showtable['Avg_row_length'], 0, $number_decimal_separator, $number_thousands_separator) . "\n"; ?>
+                    <?php echo PMA_formatNumber($showtable['Avg_row_length'], 0) . "\n"; ?>
                 </td>
             </tr>
                     <?php
@@ -472,7 +424,7 @@ foreach ($the_tables as $key => $table) {
             <tr>
                 <td><?php echo ucfirst($strNext); ?>&nbsp;Autoindex</td>
                 <td align="right">
-                    <?php echo number_format($showtable['Auto_increment'], 0, $number_decimal_separator, $number_thousands_separator) . "\n"; ?>
+                    <?php echo PMA_formatNumber($showtable['Auto_increment'], 0) . "\n"; ?>
                 </td>
             </tr>
                     <?php
@@ -519,7 +471,7 @@ foreach ($the_tables as $key => $table) {
         } // end if ($cfg['ShowStats'])
     }
     if ($multi_tables) {
-        unset($ret_keys, $num_rows, $show_comment);
+        unset($num_rows, $show_comment);
         echo '<hr />' . "\n";
     } // end if
     echo '</div>' . "\n";
@@ -531,7 +483,7 @@ foreach ($the_tables as $key => $table) {
  */
 ?>
 
-<script type="text/javascript" language="javascript">
+<script type="text/javascript">
 //<![CDATA[
 function printPage()
 {
