@@ -7,7 +7,8 @@
  * and include sql.php to execute it
  *
  * @todo display search form again if no results from previous search
- * @version $Id: tbl_select.php 11417 2008-07-21 16:41:17Z lem9 $
+ * @version $Id$
+ * @package phpMyAdmin
  */
 
 /**
@@ -232,7 +233,7 @@ while (list($operator) = each($GLOBALS['cfg']['UnaryOperators'])) {
         ?>
                     <script type="text/javascript">
                     //<![CDATA[
-                    document.write('<a title="<?php echo $strCalendar;?>" href="javascript:openCalendar(\'<?php echo PMA_generate_common_url();?>\', \'insertForm\', \'field_<?php echo ($i); ?>\', \'<?php echo (substr($type, 0, 9) == 'timestamp') ? 'datetime' : substr($type, 0, 9); ?>\')"><img class="calendar" src="<?php echo $pmaThemeImage; ?>b_calendar.png" alt="<?php echo $strCalendar; ?>"/></a>');
+                    document.write('<a title="<?php echo $strCalendar;?>" href="javascript:openCalendar(\'<?php echo PMA_generate_common_url();?>\', \'insertForm\', \'field_<?php echo ($i); ?>\', \'<?php echo (substr($type, 0, 9) == 'timestamp') ? 'datetime' : substr($type, 0, 9); ?>\', \'\')"><img class="calendar" src="<?php echo $pmaThemeImage; ?>b_calendar.png" alt="<?php echo $strCalendar; ?>"/></a>');
                     //]]>
                     </script>
         <?php
@@ -303,10 +304,11 @@ while (list($operator) = each($GLOBALS['cfg']['UnaryOperators'])) {
         'ASC'  => $strAscending,
         'DESC' => $strDescending
     );
-    PMA_generate_html_radio('order', $choices, 'ASC', false, true, "formelement");
+    PMA_display_html_radio('order', $choices, 'ASC', false, true, "formelement");
     unset($choices);
 ?>
 </fieldset>
+<br style="clear: both;"/>
 </div>
 </fieldset>
 <fieldset class="tblFooters">
@@ -337,8 +339,11 @@ else {
     } else {
         $param = PMA_backquote($param);
         $sql_query .= implode(', ', $param);
-        unset($param);
     } // end if
+     
+    // avoid a loop, for example when $cfg['DefaultTabTable'] is set 
+    // to 'tbl_select.php'
+    unset($param);
 
     $sql_query .= ' FROM ' . PMA_backquote($table);
 
